Stan Math Library: stan/math/prim/arr/meta/is_vector.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

is_vector.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_ARR_META_IS_VECTOR_HPP
2 #define STAN_MATH_PRIM_ARR_META_IS_VECTOR_HPP
3
4 #include <stan/math/prim/scal/meta/is_vector.hpp>
5 #include <vector>
6
7 namespace stan {
8
9 // FIXME: use boost::type_traits::remove_all_extents to
10 // extend to array/ptr types
11
12 template <typename T>
13 struct is_vector<const T> {
14 enum { value = is_vector<T>::value };
15 typedef T type;
16 };
17 template <typename T>
18 struct is_vector<std::vector<T> > {
19 enum { value = 1 };
20 typedef T type;
21 };
22 }
23 #endif
24
stan
Definition: log_sum_exp.hpp:8
stan::is_vector< std::vector< T > >::type
T type
Definition: is_vector.hpp:20
is_vector.hpp
std
Definition: std_numeric_limits.hpp:7
stan::is_vector
Definition: is_vector.hpp:10
stan::is_vector::value
Definition: is_vector.hpp:11
stan::is_vector< const T >::type
T type
Definition: is_vector.hpp:15

[ Stan Home Page ] © 2011–2016, Stan Development Team.